You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by be...@apache.org on 2008/03/14 21:49:01 UTC

svn commit: r637259 - /maven/plugin-tools/trunk/maven-plugin-tools-javadoc/src/main/java/org/apache/maven/tools/plugin/javadoc/MojoPhaseTypeTaglet.java

Author: bentmann
Date: Fri Mar 14 13:48:58 2008
New Revision: 637259

URL: http://svn.apache.org/viewvc?rev=637259&view=rev
Log:
o Fixed typo

Modified:
    maven/plugin-tools/trunk/maven-plugin-tools-javadoc/src/main/java/org/apache/maven/tools/plugin/javadoc/MojoPhaseTypeTaglet.java

Modified: maven/plugin-tools/trunk/maven-plugin-tools-javadoc/src/main/java/org/apache/maven/tools/plugin/javadoc/MojoPhaseTypeTaglet.java
URL: http://svn.apache.org/viewvc/maven/plugin-tools/trunk/maven-plugin-tools-javadoc/src/main/java/org/apache/maven/tools/plugin/javadoc/MojoPhaseTypeTaglet.java?rev=637259&r1=637258&r2=637259&view=diff
==============================================================================
--- maven/plugin-tools/trunk/maven-plugin-tools-javadoc/src/main/java/org/apache/maven/tools/plugin/javadoc/MojoPhaseTypeTaglet.java (original)
+++ maven/plugin-tools/trunk/maven-plugin-tools-javadoc/src/main/java/org/apache/maven/tools/plugin/javadoc/MojoPhaseTypeTaglet.java Fri Mar 14 13:48:58 2008
@@ -44,7 +44,7 @@
  * </pre>
  * <b>Note</b>: This taglet is similar to call the <code>Javadoc</code> tool with the following:
  * <pre>
  * javadoc ... -tag 'phase:t:Is binded to the specified phase of the standard build lifecycle:'
  * </pre>
  *
  * @see <a href="package-summary.html#package_description">package-summary.html</a>
@@ -57,7 +57,7 @@
 {
     private static final String NAME = JavaMojoAnnotation.PHASE;
 
-    protected static final String HEADER = "Is binded to the specified phase of the standard build lifecycle";
+    protected static final String HEADER = "Is bound to the specified phase of the standard build lifecycle";
 
     /**
      * @return By default, return the string defined in {@linkplain #HEADER}.
@@ -44,7 +44,7 @@
  * <b>Note</b>: This taglet is similar to call the <code>Javadoc</code> tool with the following:
  * <pre>
- * javadoc ... -tag 'phase:t:Is binded to the specified phase of the standard build lifecycle:'
+ * javadoc ... -tag 'phase:t:Is bound to the specified phase of the standard build lifecycle:'
  * </pre>
  *